identity

package
v0.0.0-...-091ba8a Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 16, 2020 License: Apache-2.0 Imports: 0 Imported by: 0

Documentation

Overview

Package identity provides build identity data set at compile time by govvv. See https://github.com/ahmetb/govvv for details.

Index

Constants

This section is empty.

Variables

var (
	BuildDate  string
	GitBranch  string
	GitCommit  string
	GitState   string
	GitSummary string
	Version    string
)

Define variables for build metadata set at compile time by govvv.

Functions

This section is empty.

Types

type Metadata

type Metadata struct {
	BuildDate  string `json:"buildDate"`
	GitBranch  string `json:"gitBranch"`
	GitCommit  string `json:"gitCommit"`
	GitState   string `json:"gitState"`
	GitSummary string `json:"gitSummary"`
	Version    string `json:"version"`
}

Metadata includes useful data about a build.

func GetMetadata

func GetMetadata() Metadata

GetMetadata returns the build metadata.

Jump to